Sophie

Sophie

distrib > Fedora > 15 > i386 > by-pkgid > 2546ffb3ea49dcdd93d428c76e1814be > files > 29

gnome-libs-1.4.2-18.fc15.src.rpm

--- gnome-libs-1.4.2/libgnome/gnome-url.c	2007-10-26 09:37:05.000000000 +0100
+++ gnome-libs-1.4.2/libgnome/gnome-url.c	2007-10-26 09:43:37.000000000 +0100
@@ -31,7 +31,7 @@
 
 static gchar *uri_get_file_uri_from_ghelp_uri (const gchar *path);
 
-#define DEFAULT_HANDLER "htmlview \"%s\""
+#define DEFAULT_HANDLER "xdg-open \"%s\""
 
 static gchar *
 gnome_url_default_handler (const char *protocol)
@@ -74,7 +74,7 @@
 			      strcmp (protocol, "man") == 0)) {
 				return app;
 			} else {
                                 /* always force use of htmlview */
                                 default_handler = DEFAULT_HANDLER;
                         }
 		} else {
@@ -84,7 +84,7 @@
                              strcmp (protocol, "man") == 0)) {
                                 default_handler = str;
                         } else {
-                                /* force htmlview */
+                                /* force xdg-open */
                                 default_handler = DEFAULT_HANDLER;
                         }
                 }
@@ -141,14 +141,14 @@
 			/* We no longer have any app (other than Galeon)
 			 * that can handle both ghelp: URI's and GNOME 1
 			 * help files, so do a hardcoded translation
-			 * and then run htmlview.
+			 * and then run xdg-open.
 			 */
 			if (strstr (url, "galeon") != NULL) {
 				/* But always use Galeon for Galeon */
 				template = "galeon \"%s\"";
 			} else {
 				url = tmp_url = uri_get_file_uri_from_ghelp_uri (pos + 1);
-				template = "htmlview \"%s\"";
+				template = "xdg-open \"%s\"";
 			}
 		} else {
 			path = g_strconcat ("/Gnome/URL Handlers/", protocol, "-show", NULL);
@@ -74,7 +74,7 @@
 				return app;
 			} else {
-                                /* always force use of htmlview */
+                                /* always force use of xdg-open */
                                 default_handler = DEFAULT_HANDLER;
                         }